#---------------
# NAME
#   makefile -- Package build and installation
#---------------
# AUTHORS
#   Peter G Baum, 2005
#   William J Giddings. 2009-2018
#---------------

PACKAGE_NAME := gnocl
PACKAGE_REQUIRE_NAME := Gnocl
VERSION := 0.9.96
GTKREQUIRED := 2.22

CFLAGS += -pedantic -fPIC -w -Os

TCL_VERSION := $(shell echo 'puts $$tcl_version' | tclsh)

ADDCFLAGS := -DVERSION=\"$(VERSION)\" \
	-DUSE_TCL_STUBS $(shell pkg-config --cflags gtk+-2.0) \
	-I/usr/include/tcl$(TCL_VERSION) \
	-I./includes \
	-I/usr/include/libglade-2.0 

LIBS := $(shell pkg-config \
	--libs gtk+-2.0 libglade-2.0 libnotify ) \
	-ltclstub$(TCL_VERSION)

GTK_OBJ := \
	./accelerator/accelerator.o \
	./accelerator/acceleratorGroup.o \
	\
	./application/application.o \
	\
	./buttons/arrowButton.o \
	./buttons/button.o \
	./buttons/checkButton.o \
	./buttons/colorButton.o \
	./buttons/fileChooserButton.o \
	./buttons/folderChooserButton.o \
	./buttons/fontButton.o \
	./buttons/linkButton.o \
	./buttons/radioButton.o \
	./buttons/scaleButton.o \
	./buttons/spinButton.o \
	./buttons/toggleButton.o \
	./buttons/volumeButton.o \
	\
	./calendar/calendar.o \
	\
	./choosers/fileChooser.o \
	./choosers/fontSelection.o \
	./choosers/colorSelection.o \
	./choosers/colorWheel.o \
	\
	./containers/aspectFrame.o \
	./containers/box.o \
	./containers/expander.o \
	./containers/eventBox.o \
	./containers/fixed.o \
	./containers/frame.o \
	./containers/handleBox.o \
	./containers/layout.o \
	./containers/notebook.o \
	./containers/paned.o \
	./containers/table.o \
	\
	cairo.o \
	\
	./clock/clockwidget.o \
	./clock/clock.o \
	\
	comboBox.o \
	\
	./commands/callback.o \
	./commands/commands.o \
	./commands/debug.o \
	./commands/properties.o \
	\
	./deprecated/combo.o \
	./deprecated/curve.o \
	./deprecated/fileSelection.o \
	./deprecated/gammaCurve.o \
	./deprecated/optionMenu.o \
	./deprecated/ruler.o \
	\
	./dial/gtkdial.o \
	./dial/dial.o \
	\
	./dialogs/aboutDialog.o \
	./dialogs/colorSelectionDialog.o \
	./dialogs/dialog.o \
	./dialogs/fileChooserDialog.o \
	./dialogs/fontSelectionDialog.o \
	./dialogs/message.o \
	./dialogs/recentChooserDialog.o \
	\
	draw.o \
	drawingArea.o \
	entry.o \
	\
	./entryValidate/CNP_entryValidate.o \
	./entryValidate/DND_entryValidate.o \
	./entryValidate/KB_entryValidate.o \
	./entryValidate/VAR_entryValidate.o \
	\
	./filters/blur_.o \
	./filters/_blur.o \
	./filters/brightness.o \
	./filters/colorize.o \
	./filters/contrast.o \
	./filters/emboss.o \
	./filters/fill.o \
	./filters/gamma.o \
	./filters/greyscale.o \
	./filters/invert.o \
	./filters/posterize.o \
	\
	./gnocl/gnocl.o \
	\
	iconView.o \
	infoBar.o \
	image.o \
	label.o \
	\
	./label/labelEdit.o \
	./label/labelWidget.o \
	./label/labelEntry.o \
	./label/labelText.o \
	\
	./level/gtklevel.o \
	./level/level.o \
	\
	keyFile.o \
	\
	./menu/menu.o \
	./menu/menuBar.o \
	./menu/menuCheckItem.o \
	./menu/menuItem.o \
	./menu/menuRadioItem.o \
	./menu/menuRecentChooser.o \
	./menu/menuSeparator.o \
	\
	./printing/pageSetup.o \
	./printing/pageSetupDialog.o \
	\
	pixMap.o \
	\
	./pixbuf/pixBuf.o \
	./pixbuf/pixBufFilters.o \
	./pixbuf/pixBufScreenshot.o \
	\
	./popupEntry/popupEntry.o \
	\
	./plug/plug.o \
	./plug/socket.o \
	\
	./printing/print.o \
	./printing/printDialog.o \
	./printing/printerDialog.o \
	./printing/printOperation.o \
	\
	progressBar.o \
	\
	./recent/recentChooser.o \
	./recent/recentManager.o \
	./recent/recentFilter.o \
	\
	./range/scale.o \
	./range/scroll.o \
	./range/scrolledWindow.o \
	\
	separator.o \
	spinner.o \
	statusBar.o \
	\
	./text/getMarkupString.o \
	./text/text.o \
	./text/textBuffer.o \
	./text/text_tag_pango.o \
	./textPango/gtktextviewpango.o \
	\
	./toplevels/assistant.o \
	./toplevels/splashScreen.o \
	./toplevels/window.o \
	\
	./textUndo/undo_manager.o \
	./textUndo/undo_view.o \
	\
	./ticker/mymarquee.o \
	./ticker/tickerTape.o \
	\
	./treeList/listOperations.o \
	./treeList/treeList.o \
	\
	./support/helperFuncs.o \
	./support/language.o \
	./support/parseMarkup.o \
	./support/parseOptions.o \
	./support/strings.o \
	\
	./toolbar/toolBar.o \
	./toolbar/tb_toggleButton.o \
	./toolbar/tb_radioButton.o \
	./toolbar/tb_menuButton.o \
	./toolbar/tb_button.o \
	./toolbar/tb_widget.o \
	./toolbar/tb_separator.o \
	./toolbar/tb_insert.o \
	./toolbar/richTextToolBar.o \
	\
	./toolpalette/toolPalette.o \
	./toolpalette/tp_itemGroup.o \
	./toolpalette/tp_button.o \
	\
	./pangoSerialize/pango_deserialize.o \
	./pangoSerialize/pango_serialize.o

#	pixMap.o \

.PHONY: all $(PACKAGE_NAME) versions clean install uninstall reinstall devinstall devuninstall

%.o : %.c; $(CC) -c $(CFLAGS) $(ADDCFLAGS) -o $*.o $<

all: pkgIndex.tcl $(PACKAGE_NAME).so ;

$(PACKAGE_NAME): $(PACKAGE_NAME).so ;

$(PACKAGE_NAME).so: $(GTK_OBJ)
	$(CC) -shared -o $@ $(GTK_OBJ) $(LIBS)

versions:
	@echo "Gnocl $(VERSION)"
	@echo "Gtk+  $(shell pkg-config --modversion gtk+-2.0) ($(GTKREQUIRED) or later required)" 
	@echo "Tcl   $(TCL_VERSION)"

clean:
	rm -f $(GTK_OBJ) $(PACKAGE_NAME).so

getGtk2libs:
	sudo apt-get install gtk2.0
	sudo apt-get install build-essential libgtk2.0-dev

install:
	./install.tcl $(PACKAGE_REQUIRE_NAME) $(VERSION) $(PACKAGE_NAME) install	

uninstall:
	./install.tcl $(PACKAGE_REQUIRE_NAME) $(VERSION) $(PACKAGE_NAME) uninstall

reinstall:
	./install.tcl $(PACKAGE_REQUIRE_NAME) $(VERSION) $(PACKAGE_NAME) uninstall
	./install.tcl $(PACKAGE_REQUIRE_NAME) $(VERSION) $(PACKAGE_NAME) install

test:
	( \
	cd ../demo; \
	./doTests; \
	cd ../src; \
	)

getLibs:
	sudo ./install-devlibs.tcl

installHeader:
	sudo cp gnocl*.h /usr/include

devinstall:
	ar cr libgnocl-$(VERSION).a $(GTK_OBJ)
	cp libgnocl*.a /usr/lib
	cp gnocl*.h /usr/include
	rm libgnocl*.a

devuninstall:
	rm /usr/include/gnocl*.h
	rm /usr/lib/libgnocl*.a

devreinstall:
	rm /usr/include/gnocl*.h
	rm /usr/lib/libgnocl*.a
	ar cr libgnocl-$(VERSION).a $(GTK_OBJ)
	cp libgnocl*.a /usr/lib
	cp gnocl*.h /usr/include
	rm libgnocl*.a

options:
	@echo "Usage: make <option>"
	@echo "all"
	@echo "clean"
	@echo "getGtk2libs"
	@echo "devinstall"
	@echo "devuninstall"
	@echo "getLibs"
	@echo "install"
	@echo "installHeader"
	@echo "options"
	@echo "reinstall"
	@echo "test"
	@echo "uninstall"
	@echo "versions"
			
# cat /etc/os-release
# lsb_release -a
	
